@@ -49,7 +49,6 @@
 #include <libgnome/gnome-util.h>
 
 #include <libxml/parser.h>
-#include <libxml/xmlmemory.h>
 
 #include <libgnomevfs/gnome-vfs-utils.h>
 
@@ -2602,7 +2601,7 @@ main(int argc, char *argv[])
 	
         return nautilus_view_standard_main ("nautilus-news",
                                             VERSION,
-                                            PACKAGE,
+                                            GETTEXT_PACKAGE,
                                             GNOMELOCALEDIR,
                                             argc,
                                             argv,
