@@ -370,10 +370,6 @@ static const PreferenceDefault preference_defaults[] = {
 	  NULL, NULL,
 	  "speed_tradeoff"
 	},
-	{ NAUTILUS_PREFERENCES_SMOOTH_GRAPHICS_MODE,
-	  PREFERENCE_BOOLEAN,
-	  GINT_TO_POINTER (TRUE)
-	},
 	{ NAUTILUS_PREFERENCES_PREVIEW_SOUND,
 	  PREFERENCE_INTEGER,
 	  GINT_TO_POINTER (NAUTILUS_SPEED_TRADEOFF_LOCAL_ONLY),
@@ -711,11 +707,7 @@ global_preferences_install_defaults (void)
 static gpointer
 default_font_callback (void)
 {
-	if (eel_dumb_down_for_multi_byte_locale_hack ()) {
-		return g_strdup ("fixed");
-	}
-
-	return g_strdup ("helvetica");
+	return g_strdup ("sans");
 }
 
 static int
