@@ -39,11 +39,13 @@
 #include "nautilus-theme.h"
 #include "nautilus-thumbnails.h"
 #include "nautilus-trash-monitor.h"
+#include <eel/eel-debug.h>
 #include <eel/eel-gdk-extensions.h>
 #include <eel/eel-gdk-pixbuf-extensions.h>
 #include <eel/eel-gdk-pixbuf-extensions.h>
 #include <eel/eel-glib-extensions.h>
 #include <eel/eel-gtk-macros.h>
+#include <eel/eel-pango-extensions.h>
 #include <eel/eel-string.h>
 #include <eel/eel-vfs-extensions.h>
 #include <gtk/gtksignal.h>
@@ -54,6 +56,7 @@
 #include <libgnomevfs/gnome-vfs-mime-monitor.h>
 #include <libgnomevfs/gnome-vfs-ops.h>
 #include <libgnomevfs/gnome-vfs-types.h>
+#include <libgnomevfs/gnome-vfs-utils.h>
 #include <librsvg/rsvg.h>
 #include <stdio.h>
 #include <string.h>
@@ -147,7 +150,6 @@ typedef struct {
 
 	/* frames to use for thumbnail icons */
 	GdkPixbuf *thumbnail_frame;
-	GdkPixbuf *thumbnail_frame_aa;
 } NautilusIconFactory;
 
 #define NAUTILUS_ICON_FACTORY(obj) \
@@ -189,7 +191,6 @@ typedef struct {
 	guint nominal_height;
 	guint maximum_width;
 	guint maximum_height;
-	gboolean optimized_for_aa;
 } IconSizeRequest;
 
 /* The key to a hash table that holds the scaled icons as pixbufs. */
@@ -203,9 +204,6 @@ typedef struct {
 	GdkPixbuf *pixbuf;
 	NautilusIconDetails details;
 
-	/* If true, outside clients have refs to the pixbuf. */
-	gboolean outstanding;
-
 	/* Number of internal clients with refs to the pixbuf. */
 	guint internal_ref_count;
 
@@ -289,7 +287,7 @@ get_icon_factory (void)
 				  G_CALLBACK (mime_type_data_changed_callback),
 				  NULL);
 
-		g_atexit (destroy_icon_factory);
+		eel_debug_call_at_shutdown (destroy_icon_factory);
         }
         return global_icon_factory;
 }
@@ -331,9 +329,9 @@ check_recently_used_list (void)
 	g_assert (count == factory->recently_used_count);
 }
 
-/* load the thumbnail frames for both the anti-aliased and non-aa cases */
+/* load the thumbnail frame */
 static void
-load_thumbnail_frames (NautilusIconFactory *factory)
+load_thumbnail_frame (NautilusIconFactory *factory)
 {
 	char *image_path;
 	
@@ -343,13 +341,6 @@ load_thumbnail_frames (NautilusIconFactory *factory)
 	}
 	factory->thumbnail_frame = gdk_pixbuf_new_from_file (image_path, NULL);
 	g_free (image_path);
-	
-	image_path = nautilus_theme_get_image_path ("thumbnail_frame.aa.png");
-	if (factory->thumbnail_frame_aa != NULL) {
-		g_object_unref (factory->thumbnail_frame_aa);
-	}
-	factory->thumbnail_frame_aa = gdk_pixbuf_new_from_file (image_path, NULL);
-	g_free (image_path);
 }
 
 static void
@@ -365,7 +356,7 @@ nautilus_icon_factory_init (NautilusIconFactory *factory)
 	factory->recently_used_dummy_head.next = &factory->recently_used_dummy_head;
 	factory->recently_used_dummy_head.prev = &factory->recently_used_dummy_head;
 
-	load_thumbnail_frames (factory);
+	load_thumbnail_frame (factory);
 }
 
 static void
@@ -381,7 +372,7 @@ nautilus_icon_factory_class_init (NautilusIconFactoryClass *class)
 		                G_SIGNAL_RUN_LAST,
 		                0,
 		                NULL, NULL,
-		                gtk_marshal_VOID__VOID,
+		                g_cclosure_marshal_VOID__VOID,
 		                G_TYPE_NONE, 0);
 
 	object_class->destroy = nautilus_icon_factory_destroy;
@@ -394,26 +385,6 @@ cache_key_destroy (CacheKey *key)
 	g_free (key);
 }
 
-#if GNOME2_CONVERSION_COMPLETE
-static void
-mark_icon_not_outstanding (GdkPixbuf *pixbuf, gpointer callback_data)
-{
-	NautilusIconFactory *factory;
-	CacheIcon *icon;
-
-	g_assert (callback_data == NULL);
-
-	factory = get_icon_factory ();
-
-	icon = g_hash_table_lookup (factory->cache_icons, pixbuf);
-        g_return_if_fail (icon != NULL);
-	g_return_if_fail (icon->pixbuf == pixbuf);
-	g_return_if_fail (icon->outstanding);
-
-	icon->outstanding = FALSE;
-}
-#endif
- 
 static CacheIcon *
 cache_icon_new (GdkPixbuf *pixbuf,
 		IconRequest request,
@@ -430,10 +401,6 @@ cache_icon_new (GdkPixbuf *pixbuf,
 
 	/* Grab the pixbuf since we are keeping it. */
 	g_object_ref (pixbuf);
-#if GNOME2_CONVERSION_COMPLETE
-	gdk_pixbuf_set_last_unref_handler
-		(pixbuf, mark_icon_not_outstanding, NULL);
-#endif
 
 	/* Make the icon. */
 	icon = g_new0 (CacheIcon, 1);
@@ -516,18 +483,7 @@ cache_icon_unref (CacheIcon *icon)
 	/* Remove from the cache icons table. */
 	g_hash_table_remove (factory->cache_icons, icon->pixbuf);
 
-	/* Since it's no longer in the cache, we don't need to notice the last unref. */
-#if GNOME2_CONVERSION_COMPLETE
-	gdk_pixbuf_set_last_unref_handler (icon->pixbuf, NULL, NULL);
-#endif
-
-	/* Let go of the pixbuf if we were holding a reference to it.
-	 * If it was still outstanding, we didn't have a reference to it,
-	 * and we were counting on the unref handler to catch it.
-	 */
-	if (!icon->outstanding) {
-		g_object_unref (icon->pixbuf);
-	}
+	g_object_unref (icon->pixbuf);
 
 	g_free (icon);
 }
@@ -587,9 +543,6 @@ nautilus_icon_factory_destroy (GtkObject *object)
 	if (factory->thumbnail_frame != NULL) {
 		g_object_unref (factory->thumbnail_frame);
 	}
-	if (factory->thumbnail_frame_aa != NULL) {
-		g_object_unref (factory->thumbnail_frame_aa);
-	}
 
         g_free (factory->theme.current.name);
         g_free (factory->theme.fallback.name);
@@ -612,7 +565,7 @@ nautilus_icon_factory_possibly_free_cached_icon (gpointer key,
 	}
 
 	/* Don't free a cache entry if the pixbuf is still in use. */
-	if (icon->outstanding) {
+	if (G_OBJECT (icon->pixbuf)->ref_count > 1) {
 		return FALSE;
 	}
 
@@ -709,7 +662,7 @@ is_theme_in_user_directory (const char *theme_name)
 	themes_directory = nautilus_make_path (user_directory, "themes");
 	this_theme_directory = nautilus_make_path (themes_directory, theme_name);
 	
-	result = g_file_exists (this_theme_directory);
+	result = g_file_test (this_theme_directory, G_FILE_TEST_EXISTS);
 	
 	g_free (user_directory);
 	g_free (themes_directory);
@@ -844,6 +797,10 @@ icon_theme_changed_callback (gpointer user_data)
 	}
 	icon_fallback_theme = nautilus_theme_get_theme_data ("icon-images", "default_theme");
 
+	if (icon_fallback_theme == NULL) {
+		icon_fallback_theme = g_strdup ("default");
+	}
+
 	factory = get_icon_factory ();
 
 	if (eel_strcmp (icon_theme, factory->theme.current.name) != 0
@@ -854,9 +811,9 @@ icon_theme_changed_callback (gpointer user_data)
 		set_theme_name (&factory->theme.fallback, icon_fallback_theme);
 		
 		nautilus_icon_factory_clear ();
-		load_thumbnail_frames (factory);
+		load_thumbnail_frame (factory);
 		g_signal_emit (factory,
-				 signals[ICONS_CHANGED], 0);
+			       signals[ICONS_CHANGED], 0);
 	}
 
 	g_free (icon_theme);
@@ -1058,7 +1015,7 @@ nautilus_scalable_icon_equal (gconstpointer a,
 }
 
 static gboolean
-should_display_image_file_as_itself (NautilusFile *file, gboolean optimized_for_aa)
+should_display_image_file_as_itself (NautilusFile *file)
 {
 	static int show_thumbnails_auto_value;
 	static gboolean show_thumbnail_auto_value_registered;
@@ -1167,7 +1124,7 @@ nautilus_icon_factory_get_icon_for_file (NautilusFile *file, const char *modifie
 		file_size = nautilus_file_get_size (file);
 		if (eel_istr_has_prefix (mime_type, "image/")
 		    && is_supported_mime_type (mime_type)
-		    && should_display_image_file_as_itself (file, TRUE)) {
+		    && should_display_image_file_as_itself (file)) {
 			if (file_size < SELF_THUMBNAIL_SIZE_THRESHOLD && is_local) {
 				uri = nautilus_file_get_uri (file);
 			} else if (strstr (file_uri, "/.thumbnails/") == NULL
@@ -1426,7 +1383,7 @@ get_next_icon_size_to_try (guint target_size, guint *current_size)
 static GdkPixbuf *
 load_pixbuf_svg (const char *path, guint size_in_pixels, gboolean is_emblem)
 {
-	double actual_size_in_pixels, zoom;
+	double actual_size_in_pixels;
 	
 	/* FIXME: the nominal size of .svg emblems is too large, so we scale it
 	 * down here if the file is an emblem. This code should be removed
@@ -1437,9 +1394,8 @@ load_pixbuf_svg (const char *path, guint size_in_pixels, gboolean is_emblem)
 	} else {
 		actual_size_in_pixels = size_in_pixels;
 	}
-	zoom = actual_size_in_pixels / NAUTILUS_ICON_SIZE_STANDARD;
-	
-	return rsvg_pixbuf_from_file_at_zoom (path, zoom, zoom, NULL);
+
+	return rsvg_pixbuf_from_file_at_max_size (path, actual_size_in_pixels, actual_size_in_pixels, NULL);
 }
 
 static gboolean
@@ -1505,8 +1461,7 @@ static GdkPixbuf *
 load_icon_from_path (const char *path,
 		     guint size_in_pixels,
 		     gboolean custom,
-		     gboolean is_emblem,  /* for emblem scaling hack only */
-		     gboolean optimized_for_aa)
+		     gboolean is_emblem  /* for emblem scaling hack only */)
 {
 	/* Get the icon. */
 	if (path == NULL) {
@@ -1525,7 +1480,7 @@ load_icon_from_path (const char *path,
 	
 	/* if it's a thumbnail, frame it if necessary */
 	if (strstr (path, "/.thumbnails/") != NULL) {
-		return nautilus_thumbnail_load_framed_image (path, optimized_for_aa);
+		return nautilus_thumbnail_load_framed_image (path);
 	}
 	
 	return gdk_pixbuf_new_from_file (path, NULL);
@@ -1535,19 +1490,17 @@ static GdkPixbuf *
 load_named_icon (const char *name,
 		 const char *modifier,
 		 guint size_in_pixels,
-		 gboolean optimized_for_aa,
 		 NautilusIconDetails *details)
 {
 	char *path;
 	GdkPixbuf *pixbuf;
 
-	path = nautilus_get_icon_file_name (&get_icon_factory ()->theme, name, modifier,
-					    size_in_pixels, optimized_for_aa,
+	path = nautilus_get_icon_file_name (&get_icon_factory ()->theme,
+					    name, modifier, size_in_pixels,
 					    details);
 	
 	pixbuf = load_icon_from_path (path, size_in_pixels, FALSE,
-				      eel_str_has_prefix (name, NAUTILUS_EMBLEM_NAME_PREFIX),
-				      optimized_for_aa);
+				      eel_str_has_prefix (name, NAUTILUS_EMBLEM_NAME_PREFIX));
 
 	g_free (path);
 
@@ -1570,7 +1523,6 @@ is_generic_icon_name (const char *name)
 static CacheIcon *
 load_specific_icon (NautilusScalableIcon *scalable_icon,
 		    guint size_in_pixels,
-		    gboolean optimized_for_aa,
 		    IconRequest type)
 {
 	NautilusIconDetails details;
@@ -1586,7 +1538,7 @@ load_specific_icon (NautilusScalableIcon *scalable_icon,
 	if (type == REQUEST_PICKY_CUSTOM_ONLY) {
 		/* We don't support custom icons that are not local here. */
 		path = gnome_vfs_get_local_path_from_uri (scalable_icon->uri);
-		pixbuf = load_icon_from_path (path, size_in_pixels, TRUE, FALSE, optimized_for_aa);
+		pixbuf = load_icon_from_path (path, size_in_pixels, TRUE, FALSE);
 		g_free (path);
 	} else {
 		mime_type_icon_name = get_mime_type_icon_without_suffix (scalable_icon->mime_type);
@@ -1604,8 +1556,7 @@ load_specific_icon (NautilusScalableIcon *scalable_icon,
 			((type == REQUEST_PICKY_BY_NAME_FIRST_CHOICE)
 			 ? first_choice_name : second_choice_name,
 			 scalable_icon->modifier,
-			 size_in_pixels,
-			 optimized_for_aa, &details);
+			 size_in_pixels, &details);
 		g_free (mime_type_icon_name);
 	}
 
@@ -1624,6 +1575,7 @@ load_specific_icon (NautilusScalableIcon *scalable_icon,
 static void
 destroy_fallback_icon (void)
 {
+#if 0
 	CacheIcon *icon;
 
 	icon = fallback_icon;
@@ -1631,13 +1583,13 @@ destroy_fallback_icon (void)
 	cache_icon_ref (icon);
 	fallback_icon = NULL;
 	cache_icon_unref (icon);
+#endif
 }
 
 /* This load function is not allowed to return NULL. */
 static CacheIcon *
 load_icon_for_scaling (NautilusScalableIcon *scalable_icon,
 		       guint requested_size,
-		       gboolean optimized_for_aa,
 		       guint *actual_size_result)
 {
 	CacheIcon *icon;
@@ -1653,7 +1605,6 @@ load_icon_for_scaling (NautilusScalableIcon *scalable_icon,
 
 	size_request.maximum_width = MAXIMUM_ICON_SIZE * requested_size / NAUTILUS_ZOOM_LEVEL_STANDARD;
 	size_request.maximum_height = size_request.maximum_width;
-	size_request.optimized_for_aa = optimized_for_aa;
 
 	for (i = 0; i < G_N_ELEMENTS (requests); i++) {
 		actual_size = 0;
@@ -1685,7 +1636,7 @@ load_icon_for_scaling (NautilusScalableIcon *scalable_icon,
 			 NULL);
 		fallback_icon = cache_icon_new (pixbuf, FALSE, FALSE, NULL);
 		fallback_icon->is_fallback = TRUE;
-		g_atexit (destroy_fallback_icon);
+		eel_debug_call_at_shutdown (destroy_fallback_icon);
 	}
 
 	*actual_size_result = NAUTILUS_ICON_SIZE_STANDARD;
@@ -1804,7 +1755,6 @@ load_icon_scale_if_necessary (NautilusScalableIcon *scalable_icon,
 	/* Load the icon that's closest in size to what we want. */
 	icon = load_icon_for_scaling (scalable_icon,
 				      size->nominal_width,
-				      size->optimized_for_aa,
 				      &nominal_actual_size);
 	
 	/* Scale the pixbuf to the size we want. */
@@ -1951,7 +1901,7 @@ get_icon_from_cache (NautilusScalableIcon *scalable_icon,
 			icon = NULL;
 		}
 	}
-	
+
 	if (icon == NULL) {
 		/* Not in the table, so load the image. */
 		/* If we're picky, then we want the image only if this exact
@@ -1968,7 +1918,6 @@ get_icon_from_cache (NautilusScalableIcon *scalable_icon,
 			/* Get the image. */
 			icon = load_specific_icon (scalable_icon,
 						   size->nominal_width,
-						   size->optimized_for_aa,
 						   type);
 			if (icon == NULL) {
 				return NULL;
@@ -1999,7 +1948,7 @@ get_icon_from_cache (NautilusScalableIcon *scalable_icon,
 		nautilus_scalable_icon_ref (scalable_icon);
 		key->scalable_icon = scalable_icon;
 		key->size = *size;
-		
+
 		/* Add the item to the hash table. */
 		g_assert (g_hash_table_lookup (hash_table, key) == NULL);
 		g_hash_table_insert (hash_table, key, icon);
@@ -2023,7 +1972,6 @@ nautilus_icon_factory_get_pixbuf_for_icon (NautilusScalableIcon *scalable_icon,
 					   guint nominal_height,
 					   guint maximum_width,
 					   guint maximum_height,
-					   gboolean optimized_for_aa,
 					   NautilusEmblemAttachPoints *attach_points,
 					   gboolean wants_default)
 {
@@ -2035,7 +1983,6 @@ nautilus_icon_factory_get_pixbuf_for_icon (NautilusScalableIcon *scalable_icon,
 	size.nominal_height = nominal_width;
 	size.maximum_width = maximum_width;
 	size.maximum_height = maximum_height;
-	size.optimized_for_aa = optimized_for_aa;
 	icon = get_icon_from_cache (scalable_icon, &size, REQUEST_NORMAL);
 
 	if (attach_points != NULL) {
@@ -2048,19 +1995,8 @@ nautilus_icon_factory_get_pixbuf_for_icon (NautilusScalableIcon *scalable_icon,
 		return NULL;
 	}
 	
-	/* The first time we hand out an icon we just leave it with a
-	 * single ref (we'll get called back for the unref), but
-	 * subsequent times we add additional refs.
-	 */
 	pixbuf = icon->pixbuf;
-	if (!icon->outstanding) {
-		icon->outstanding = TRUE;
-#ifndef GNOME2_CONVERSION_COMPLETE
-		g_object_ref (pixbuf);
-#endif
-	} else {
-		g_object_ref (pixbuf);
-	}
+	g_object_ref (pixbuf);
 	cache_icon_unref (icon);
 
 	return pixbuf;
@@ -2072,12 +2008,11 @@ cache_key_hash (gconstpointer p)
 	const CacheKey *key;
 
 	key = p;
-	return (((((((((GPOINTER_TO_UINT (key->scalable_icon) << 4)
-		       ^ key->size.nominal_width) << 4)
-		     ^ key->size.nominal_height) << 4)
-		   ^ key->size.maximum_width) << 4)
-		 ^ key->size.maximum_height) << 1)
-		| key->size.optimized_for_aa;
+	return ((((((((GPOINTER_TO_UINT (key->scalable_icon) << 4)
+		      ^ key->size.nominal_width) << 4)
+		    ^ key->size.nominal_height) << 4)
+		  ^ key->size.maximum_width) << 4)
+		^ key->size.maximum_height);
 }
 
 static gboolean
@@ -2092,8 +2027,7 @@ cache_key_equal (gconstpointer a, gconstpointer b)
 		&& key_a->size.nominal_width == key_b->size.nominal_width
 		&& key_a->size.nominal_height == key_b->size.nominal_height
 		&& key_a->size.maximum_width == key_b->size.maximum_width
-		&& key_a->size.maximum_height == key_b->size.maximum_height
-		&& key_a->size.optimized_for_aa == key_b->size.optimized_for_aa;
+		&& key_a->size.maximum_height == key_b->size.maximum_height;
 }
 
 /* Return nominal icon size for given zoom level.
@@ -2130,8 +2064,7 @@ nautilus_get_icon_size_for_zoom_level (NautilusZoomLevel zoom_level)
 GdkPixbuf *
 nautilus_icon_factory_get_pixbuf_for_file (NautilusFile *file,
 					   const char *modifer,
-					   guint size_in_pixels,
-					   gboolean optimized_for_aa)
+					   guint size_in_pixels)
 {
 	NautilusScalableIcon *icon;
 	GdkPixbuf *pixbuf;
@@ -2145,7 +2078,6 @@ nautilus_icon_factory_get_pixbuf_for_file (NautilusFile *file,
 		(icon,
 		 size_in_pixels, size_in_pixels,
 		 size_in_pixels, size_in_pixels,
-		 optimized_for_aa,
 		 NULL, TRUE);
 	nautilus_scalable_icon_unref (icon);
 
@@ -2156,8 +2088,7 @@ nautilus_icon_factory_get_pixbuf_for_file (NautilusFile *file,
 GdkPixbuf *
 nautilus_icon_factory_get_pixbuf_from_name (const char *icon_name,
 					    const char *modifier,
-					    guint size_in_pixels,
-					    gboolean optimized_for_aa)
+					    guint size_in_pixels)
 {
 	GdkPixbuf *pixbuf;
 	NautilusScalableIcon *icon;
@@ -2166,22 +2097,15 @@ nautilus_icon_factory_get_pixbuf_from_name (const char *icon_name,
 	pixbuf = nautilus_icon_factory_get_pixbuf_for_icon (icon,
 							    size_in_pixels, size_in_pixels,
 							    size_in_pixels, size_in_pixels,
-							    optimized_for_aa,
 							    NULL, TRUE); 	
 	nautilus_scalable_icon_unref (icon);	
 	return pixbuf;
 }
 									  
 GdkPixbuf *
-nautilus_icon_factory_get_thumbnail_frame (gboolean anti_aliased)
+nautilus_icon_factory_get_thumbnail_frame (void)
 {
-	NautilusIconFactory *icon_factory;
-	icon_factory = get_icon_factory ();
-	if (anti_aliased) {
-		return icon_factory->thumbnail_frame_aa;
-	} else {
-		return icon_factory->thumbnail_frame;
-	}
+	return get_icon_factory ()->thumbnail_frame;
 }
 
 static gboolean
@@ -2201,94 +2125,74 @@ embedded_text_rect_usable (ArtIRect embedded_text_rect)
 	return TRUE;
 }
 
-#if GNOME2_CONVERSION_COMPLETE
-
 static gboolean embedded_text_preferences_callbacks_added = FALSE;
-static EelScalableFont *embedded_text_font = NULL;
+static PangoFontDescription *embedded_text_font = NULL;
 
 static void
 embedded_text_font_changed_callback (gpointer callback_data)
 {
 	gboolean clear_cache;
-
+	char *font_name;
+	
 	clear_cache = GPOINTER_TO_INT (callback_data);
 
-	embedded_text_font = nautilus_global_preferences_get_default_smooth_font ();
+	if (embedded_text_font != NULL) {
+		pango_font_description_free (embedded_text_font);
+	}
+
+	font_name = eel_preferences_get (NAUTILUS_PREFERENCES_DEFAULT_FONT);
+	embedded_text_font = pango_font_description_from_string (font_name);
+	g_free (font_name);
+
+	pango_font_description_set_size (embedded_text_font,
+					 EMBEDDED_TEXT_FONT_SIZE * PANGO_SCALE);
 
 	if (clear_cache) {
 		nautilus_icon_factory_clear ();
 	}
 }
 
-static void
-embedded_text_font_free (void)
-{
-	if (embedded_text_font == NULL) {
-		return;
-	}
-	
-	g_object_unref (embedded_text_font);
-	embedded_text_font = NULL;
-}
-
-#endif
-
 static GdkPixbuf *
 embed_text (GdkPixbuf *pixbuf_without_text,
-	    ArtIRect embedded_text_rect,
+	    ArtIRect text_rect,
 	    const char *text)
 {
 	GdkPixbuf *pixbuf_with_text;
+	PangoLayout *layout;
+	static PangoContext *context;
 	
 	g_return_val_if_fail (pixbuf_without_text != NULL, NULL);
 	
 	/* Quick out for the case where there's no place to embed the
 	 * text or the place is too small or there's no text.
 	 */
-	if (!embedded_text_rect_usable (embedded_text_rect) || eel_strlen (text) == 0) {
+	if (!embedded_text_rect_usable (text_rect) || eel_strlen (text) == 0) {
 		return NULL;
 	}
 
 	/* Listen for changes in embedded text (icon text preview) font preferences */
-#if GNOME2_CONVERSION_COMPLETE
 	if (!embedded_text_preferences_callbacks_added) {
 		embedded_text_preferences_callbacks_added = TRUE;
 
-		eel_preferences_add_callback (NAUTILUS_PREFERENCES_DEFAULT_SMOOTH_FONT,
+		eel_preferences_add_callback (NAUTILUS_PREFERENCES_DEFAULT_FONT,
 					      embedded_text_font_changed_callback,
 					      GINT_TO_POINTER (TRUE));
 		embedded_text_font_changed_callback (GINT_TO_POINTER (FALSE));
-
-		g_atexit (embedded_text_font_free);
 	}
-
-	g_return_val_if_fail (EEL_IS_SCALABLE_FONT (embedded_text_font), NULL);
 	
-	smooth_text_layout = eel_smooth_text_layout_new (text,
-							 eel_strlen (text),
-							 embedded_text_font,
-							 EMBEDDED_TEXT_FONT_SIZE,
-							 FALSE);
-	g_return_val_if_fail (EEL_IS_SMOOTH_TEXT_LAYOUT (smooth_text_layout), NULL);
-	eel_smooth_text_layout_set_line_spacing (smooth_text_layout, EMBEDDED_TEXT_LINE_SPACING);
-	eel_smooth_text_layout_set_empty_line_height (smooth_text_layout, EMBEDDED_TEXT_EMPTY_LINE_HEIGHT);
-#endif
+	if (context == NULL) {
+		context = eel_pango_ft2_get_context ();
+		eel_debug_call_at_shutdown_with_data (g_object_unref, context);
+	}
+	layout = pango_layout_new (context);
+	pango_layout_set_font_description (layout, embedded_text_font);
+	pango_layout_set_text (layout, text, -1);
 	
 	pixbuf_with_text = gdk_pixbuf_copy (pixbuf_without_text);
-
-#if GNOME2_CONVERSION_COMPLETE	
-	eel_smooth_text_layout_draw_to_pixbuf (smooth_text_layout,
-					       pixbuf_with_text,
-					       0,
-					       0,
-					       embedded_text_rect,
-					       GTK_JUSTIFY_LEFT,
-					       FALSE,
-					       EEL_RGB_COLOR_BLACK,
-					       EEL_OPACITY_FULLY_OPAQUE);
-	
-	g_object_unref (smooth_text_layout);
-#endif
+	eel_gdk_pixbuf_draw_layout_clipped (pixbuf_with_text,
+					    text_rect,
+					    EEL_RGB_COLOR_BLACK, layout);
+	g_object_unref (layout);
 
 	return pixbuf_with_text;
 }
