@@ -25,13 +25,12 @@
 #ifndef NAUTILUS_ICON_CONTAINER_PRIVATE_H
 #define NAUTILUS_ICON_CONTAINER_PRIVATE_H
 
-#include "nautilus-entry.h"
 #include <eel/eel-glib-extensions.h>
-#include "nautilus-icon-container.h"
-#include "nautilus-icon-dnd.h"
-#include "nautilus-icon-factory.h"
-#include "nautilus-icon-canvas-item.h"
-#include "nautilus-icon-text-item.h"
+#include <libgnomeui/gnome-icon-item.h>
+#include <libnautilus-private/nautilus-icon-canvas-item.h>
+#include <libnautilus-private/nautilus-icon-container.h>
+#include <libnautilus-private/nautilus-icon-dnd.h>
+#include <libnautilus-private/nautilus-icon-factory.h>
 
 /* An Icon. */
 
@@ -149,7 +148,7 @@ struct NautilusIconContainerDetails {
 
 	/* Renaming Details */
 	gboolean renaming;
-	NautilusIconTextItem *rename_widget;	/* Editable text item */
+	GnomeIconTextItem *rename_widget;	/* Editable text item */
 	char *original_text;			/* Copy of editable text for later compare */
 
 	/* typeahead selection state */
@@ -166,18 +165,22 @@ struct NautilusIconContainerDetails {
 
 	/* zoom level */
 	int zoom_level;
-	
-	/* fonts used to draw labels in regular mode */
-	GdkFont *label_font[NAUTILUS_ZOOM_LEVEL_LARGEST + 1];
-	int font_size_table[NAUTILUS_ZOOM_LEVEL_LARGEST + 1]; /* unused? */
+
+	/* fonts used to draw labels */
+	char *font_name;
+	int font_size_table[NAUTILUS_ZOOM_LEVEL_LARGEST + 1];
+	gboolean update_icon_font;
 
 	/* pixbuf and color for label highlighting */
 	GdkPixbuf *highlight_frame;
-	guint32 highlight_color;
+	GdkColor   highlight_color;
+	guint32    highlight_color_rgba;
 	
 	/* color for text labels */
-	guint32 label_color;
-	guint32 label_info_color;
+	GdkColor label_color;
+	GdkColor label_color_highlight;
+	GdkColor label_info_color;
+	GdkColor label_info_color_highlight;
 	
 	/* State used so arrow keys don't wander if icons aren't lined up.
 	 * Keeps track of last axis arrow key was used on.
@@ -203,8 +206,8 @@ struct NautilusIconContainerDetails {
 	gboolean reset_scroll_region_trigger;
 	
 	/* The position we are scaling to on stretch */
-	int window_x;
-	int window_y;
+	int widget_x;
+	int widget_y;
 
 	/* margins to follow, used for the desktop panel avoidance */
 	int left_margin;
@@ -243,7 +246,8 @@ gboolean      nautilus_icon_container_scroll                      (NautilusIconC
 void          nautilus_icon_container_update_scroll_region        (NautilusIconContainer *container);
 
 /* label color for items */
-guint32       nautilus_icon_container_get_label_color             (NautilusIconContainer *container,
-								   gboolean               first_line);
+GdkColor     *nautilus_icon_container_get_label_color             (NautilusIconContainer *container,
+								   gboolean               first_line,
+								   gboolean               needs_highlight);
 
 #endif /* NAUTILUS_ICON_CONTAINER_PRIVATE_H */
