@@ -33,7 +33,6 @@
 #include <eel/eel-gtk-extensions.h>
 #include <eel/eel-gtk-macros.h>
 #include <eel/eel-stock-dialogs.h>
-#include <eel/eel-dnd.h>
 #include <eel/eel-string.h>
 #include <eel/eel-vfs-extensions.h>
 #include <errno.h>
@@ -46,6 +45,7 @@
 #include <gtk/gtkwindow.h>
 #include <libgnome/gnome-i18n.h>
 #include <libgnome/gnome-config.h>
+#include <libgnome/gnome-desktop-item.h>
 #include <libgnomevfs/gnome-vfs-ops.h>
 #include <libgnomevfs/gnome-vfs-async-ops.h>
 #include <libgnomevfs/gnome-vfs-uri.h>
@@ -55,9 +55,11 @@
 #include <libnautilus-private/nautilus-bonobo-extensions.h>
 #include <libnautilus-private/nautilus-directory-background.h>
 #include <libnautilus-private/nautilus-directory.h>
+#include <libnautilus-private/nautilus-dnd.h>
 #include <libnautilus-private/nautilus-file-utilities.h>
 #include <libnautilus-private/nautilus-global-preferences.h>
 #include <libnautilus-private/nautilus-icon-container.h>
+#include <libnautilus-private/nautilus-icon-dnd.h>
 #include <libnautilus-private/nautilus-icon-factory.h>
 #include <libnautilus-private/nautilus-link.h>
 #include <libnautilus-private/nautilus-metadata.h>
@@ -130,7 +132,6 @@ gboolean                    fm_icon_view_supports_auto_layout                  (
 static void                 fm_icon_view_update_icon_container_fonts           (FMIconView            *icon_view);
 static void                 fm_icon_view_update_icon_container_font_size_table (FMIconView            *icon_view);
 static void                 fm_icon_view_update_click_mode                     (FMIconView            *icon_view);
-static void                 fm_icon_view_update_smooth_graphics_mode           (FMIconView            *icon_view);
 static gboolean             fm_icon_view_using_tighter_layout                  (FMIconView            *icon_view);
 static gboolean             fm_icon_view_get_directory_tighter_layout          (FMIconView            *icon_view,
 										NautilusFile          *file);
@@ -254,6 +255,7 @@ fm_icon_view_finalize (GObject *object)
 	preview_audio (icon_view, NULL, FALSE);
 
 	nautilus_file_list_free (icon_view->details->icons_not_positioned);
+
 	g_free (icon_view->details);
 
 	EEL_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
@@ -935,7 +937,7 @@ fm_icon_view_begin_loading (FMDirectoryView *view)
 
 	/* kill any sound preview process that is ongoing */
 	preview_audio (icon_view, NULL, FALSE);
-	
+
 	/* FIXME bugzilla.gnome.org 45060: Should use methods instead
 	 * of hardcoding desktop knowledge in here.
 	 */
@@ -944,6 +946,7 @@ fm_icon_view_begin_loading (FMDirectoryView *view)
 	} else {
 		nautilus_connect_background_to_file_metadata (icon_container, file);
 	}
+
 	
 	/* Set up the zoom level from the metadata. */
 	if (fm_directory_view_supports_zooming (FM_DIRECTORY_VIEW (icon_view))) {
@@ -1749,15 +1752,14 @@ icon_container_preview_callback (NautilusIconContainer *container,
 
 static void
 renaming_icon_callback (NautilusIconContainer *container,
-			GtkEditable *editable,
+			GtkWidget *widget,
 			gpointer callback_data)
 {
 	FMDirectoryView *directory_view;
 
 	directory_view = FM_DIRECTORY_VIEW (callback_data);
-
 	nautilus_clipboard_set_up_editable_in_control
-		(editable,
+		(GTK_EDITABLE (widget),
 		 fm_directory_view_get_bonobo_control (directory_view),
 		 TRUE);
 }
@@ -2066,6 +2068,7 @@ get_icon_text_callback (NautilusIconContainer *container,
  		*additional_text = NULL;
 		if (path != NULL) {
 			description = nautilus_link_local_get_additional_text (path);
+			g_free (path);
 			if (description)
 				*additional_text = g_strdup_printf (" \n%s\n ", description);
 			g_free (description);
@@ -2116,7 +2119,7 @@ fm_icon_view_text_attribute_names_changed (FMDirectoryView *directory_view)
 {
 	g_assert (FM_IS_ICON_VIEW (directory_view));
 
-	nautilus_icon_container_request_update_all (get_icon_container (FM_ICON_VIEW (directory_view)));	
+	nautilus_icon_container_request_update_all (get_icon_container (FM_ICON_VIEW (directory_view)));
 }
 
 static void
@@ -2124,7 +2127,7 @@ fm_icon_view_embedded_text_policy_changed (FMDirectoryView *directory_view)
 {
 	g_assert (FM_IS_ICON_VIEW (directory_view));
 
-	nautilus_icon_container_request_update_all (get_icon_container (FM_ICON_VIEW (directory_view)));	
+	nautilus_icon_container_request_update_all (get_icon_container (FM_ICON_VIEW (directory_view)));
 }
 
 static void
@@ -2132,7 +2135,7 @@ fm_icon_view_image_display_policy_changed (FMDirectoryView *directory_view)
 {
 	g_assert (FM_IS_ICON_VIEW (directory_view));
 
-	nautilus_icon_container_request_update_all (get_icon_container (FM_ICON_VIEW (directory_view)));	
+	nautilus_icon_container_request_update_all (get_icon_container (FM_ICON_VIEW (directory_view)));
 }
 
 static void
@@ -2159,14 +2162,6 @@ fm_icon_view_click_policy_changed (FMDirectoryView *directory_view)
 	fm_icon_view_update_click_mode (FM_ICON_VIEW (directory_view));
 }
 
-static void
-fm_icon_view_smooth_graphics_mode_changed (FMDirectoryView *directory_view)
-{
-	g_assert (FM_IS_ICON_VIEW (directory_view));
-
-	fm_icon_view_update_smooth_graphics_mode (FM_ICON_VIEW (directory_view));
-}
-
 static void
 default_sort_order_changed_callback (gpointer callback_data)
 {
@@ -2323,26 +2318,19 @@ icon_view_move_copy_items (NautilusIconContainer *container,
 static void
 fm_icon_view_update_icon_container_fonts (FMIconView *icon_view)
 {
-#if GNOME2_CONVERSION_COMPLETE
- 	/* font size table - this isn't exactly proportional, but it looks better than computed */
-	static guint font_size_table[NAUTILUS_ZOOM_LEVEL_LARGEST + 1] = {
-		8, 8, 10, 12, 14, 18, 18 };
 	NautilusIconContainer *icon_container;
-	GdkFont *font;
-	guint i;
-
+	char *font_name;
+	
 	icon_container = get_icon_container (icon_view);
 	g_assert (icon_container != NULL);
 
-	for (i = 0; i <= NAUTILUS_ZOOM_LEVEL_LARGEST; i++) {
-		font = nautilus_font_factory_get_font_from_preferences (font_size_table[i]);
-		g_assert (font != NULL);
-		nautilus_icon_container_set_label_font_for_zoom_level (icon_container, i, font);
-		gdk_font_unref (font);
-	}
+	font_name = eel_preferences_get (NAUTILUS_PREFERENCES_ICON_VIEW_FONT);
 
+	nautilus_icon_container_set_font_name (icon_container, font_name);
+
+	g_free (font_name);
+	
 	nautilus_icon_container_request_update_all (icon_container);
-#endif
 }
 
 static int default_zoom_level_font_size = 12;
@@ -2406,12 +2394,7 @@ fm_icon_view_update_icon_container_font_size_table (FMIconView *icon_view)
 					    max_font_size);
 
 	}
-
-	for (i = 0; i <= NAUTILUS_ZOOM_LEVEL_LARGEST; i++) {
-		g_assert (font_size_table[i] >= min_font_size);
-		g_assert (font_size_table[i] <= max_font_size);
-	}
-
+	
 	nautilus_icon_container_set_font_size_table (icon_container, font_size_table);
 	nautilus_icon_container_request_update_all (icon_container);
 }
@@ -2432,20 +2415,6 @@ fm_icon_view_update_click_mode (FMIconView *icon_view)
 						       click_mode == NAUTILUS_CLICK_POLICY_SINGLE);
 }
 
-static void
-fm_icon_view_update_smooth_graphics_mode (FMIconView *icon_view)
-{
-	NautilusIconContainer	*icon_container;
-	gboolean		smooth_graphics_mode;
-
-	icon_container = get_icon_container (icon_view);
-	g_assert (icon_container != NULL);
-
-	smooth_graphics_mode = eel_preferences_get_boolean (NAUTILUS_PREFERENCES_SMOOTH_GRAPHICS_MODE);
-	
-	nautilus_icon_container_set_anti_aliased_mode (icon_container, smooth_graphics_mode);
-}
-
 static void
 create_icon_container (FMIconView *icon_view)
 {
@@ -2533,22 +2502,14 @@ create_icon_container (FMIconView *icon_view)
 			    "layout_changed",
 			    G_CALLBACK (layout_changed_callback),
 			    directory_view);
-	g_signal_connect (icon_container,
-			    "preview",
-			    G_CALLBACK (icon_container_preview_callback),
-			    icon_view);
-	g_signal_connect (icon_container,
-			    "renaming_icon",
-			    G_CALLBACK (renaming_icon_callback),
-			    directory_view);
-	gtk_signal_connect_object (GTK_OBJECT (icon_container),
-			           "icon_stretch_started",
-			           G_CALLBACK (fm_directory_view_update_menus),
-			           GTK_OBJECT (directory_view));
-	gtk_signal_connect_object (GTK_OBJECT (icon_container),
-			           "icon_stretch_ended",
-			           G_CALLBACK (fm_directory_view_update_menus),
-			           GTK_OBJECT (directory_view));
+	g_signal_connect (icon_container, "preview",
+			  G_CALLBACK (icon_container_preview_callback), icon_view);
+	g_signal_connect (icon_container, "renaming_icon",
+			  G_CALLBACK (renaming_icon_callback), directory_view);
+	g_signal_connect_swapped (icon_container, "icon_stretch_started",
+				  G_CALLBACK (fm_directory_view_update_menus), directory_view);
+	g_signal_connect_swapped (icon_container, "icon_stretch_ended",
+				  G_CALLBACK (fm_directory_view_update_menus), directory_view);
 
 	gtk_container_add (GTK_CONTAINER (icon_view),
 			   GTK_WIDGET (icon_container));
@@ -2556,7 +2517,6 @@ create_icon_container (FMIconView *icon_view)
 	fm_icon_view_update_icon_container_fonts (icon_view);
 	fm_icon_view_update_icon_container_font_size_table (icon_view);
 	fm_icon_view_update_click_mode (icon_view);
-	fm_icon_view_update_smooth_graphics_mode (icon_view);
 
 	gtk_widget_show (GTK_WIDGET (icon_container));
 }
@@ -2566,14 +2526,10 @@ icon_view_handle_uri_list (NautilusIconContainer *container, const char *item_ur
 			   GdkDragAction action, int x, int y, FMIconView *view)
 {
 
-#if GNOME2_CONVERSION_COMPLETE
 	GList *uri_list;
-#endif
 	GList *node, *real_uri_list = NULL;
 	GnomeVFSURI *container_uri;
-#if GNOME2_CONVERSION_COMPLETE
-	GnomeDesktopEntry *entry;
-#endif
+	GnomeDesktopItem *entry;
 	GdkPoint point;
 	char *uri;
 	char *local_path;
@@ -2603,7 +2559,7 @@ icon_view_handle_uri_list (NautilusIconContainer *container, const char *item_ur
 	}
 
 	if (action == GDK_ACTION_ASK) {
-		action = eel_drag_drop_action_ask 
+		action = nautilus_drag_drop_action_ask 
 			(GDK_ACTION_MOVE | GDK_ACTION_COPY | GDK_ACTION_LINK);
 	}
 	
@@ -2631,8 +2587,7 @@ icon_view_handle_uri_list (NautilusIconContainer *container, const char *item_ur
 	 */
 	all_local = TRUE;
 	n_uris = 0;
-#if GNOME2_CONVERSION_COMPLETE
-	uri_list = gnome_vfs_uri_list_extract_uris (item_uris);
+	uri_list = nautilus_icon_dnd_uri_list_extract_uris (item_uris);
 	for (node = uri_list; node != NULL; node = node->next) {
 		gchar *sanitized_uri;
 
@@ -2644,8 +2599,7 @@ icon_view_handle_uri_list (NautilusIconContainer *container, const char *item_ur
 			all_local = FALSE;
 		n_uris++;
 	}
-	gnome_vfs_uri_list_free_strings (uri_list);
-#endif
+	nautilus_icon_dnd_uri_list_free_strings (uri_list);
 
 	if (all_local == TRUE &&
 	    (action == GDK_ACTION_COPY ||
@@ -2673,18 +2627,17 @@ icon_view_handle_uri_list (NautilusIconContainer *container, const char *item_ur
 			uri = node->data;
 			local_path = gnome_vfs_get_local_path_from_uri (uri);
 			if (local_path != NULL) {
-#if GNOME2_CONVERSION_COMPLETE
-				entry = gnome_desktop_entry_load (local_path);
+				entry = gnome_desktop_item_new_from_file (local_path, 0, NULL);
 				if (entry != NULL) {
 					/* FIXME: Handle name conflicts? */
 					nautilus_link_local_create_from_gnome_entry (entry, container_path, &point);
-					gnome_desktop_entry_free (entry);
+					gnome_desktop_item_unref (entry);
 				}
 				g_free (local_path);
 				if (entry != NULL) {
 					continue;
+
 				}
-#endif
 			}
 
 			/* Make a link from the URI alone. Generate the file
@@ -2711,9 +2664,8 @@ icon_view_handle_uri_list (NautilusIconContainer *container, const char *item_ur
 		g_free (container_path);
 	}
 	
-#if GNOME2_CONVERSION_COMPLETE
-	gnome_vfs_uri_list_free_strings (real_uri_list);
-#endif
+	nautilus_icon_dnd_uri_list_free_strings (real_uri_list);
+
 	gnome_vfs_uri_unref (container_uri);
 	g_free (container_uri_string);
 	
@@ -2752,7 +2704,6 @@ fm_icon_view_class_init (FMIconViewClass *klass)
         fm_directory_view_class->embedded_text_policy_changed = fm_icon_view_embedded_text_policy_changed;
         fm_directory_view_class->image_display_policy_changed = fm_icon_view_image_display_policy_changed;
         fm_directory_view_class->merge_menus = fm_icon_view_merge_menus;
-        fm_directory_view_class->smooth_graphics_mode_changed = fm_icon_view_smooth_graphics_mode_changed;
         fm_directory_view_class->sort_directories_first_changed = fm_icon_view_sort_directories_first_changed;
         fm_directory_view_class->start_renaming_item = fm_icon_view_start_renaming_item;
         fm_directory_view_class->text_attribute_names_changed = fm_icon_view_text_attribute_names_changed;
@@ -2768,14 +2719,12 @@ fm_icon_view_class_init (FMIconViewClass *klass)
         klass->set_directory_sort_by = fm_icon_view_real_set_directory_sort_by;
         klass->set_directory_sort_reversed = fm_icon_view_real_set_directory_sort_reversed;
         klass->set_directory_tighter_layout = fm_icon_view_real_set_directory_tighter_layout;
-
-	eel_preferences_add_auto_integer (NAUTILUS_PREFERENCES_PREVIEW_SOUND,
-					       &preview_sound_auto_value);
 }
 
 static void
 fm_icon_view_init (FMIconView *icon_view)
 {
+	static gboolean setup_sound_preview = FALSE;
 	NautilusIconContainer *icon_container;
 
         g_return_if_fail (GTK_BIN (icon_view)->child == NULL);
@@ -2785,6 +2734,12 @@ fm_icon_view_init (FMIconView *icon_view)
 
 	create_icon_container (icon_view);
 
+	if (!setup_sound_preview) {
+		eel_preferences_add_auto_integer (NAUTILUS_PREFERENCES_PREVIEW_SOUND,
+						  &preview_sound_auto_value);
+		setup_sound_preview = TRUE;
+	}
+
 	eel_preferences_add_callback_while_alive (NAUTILUS_PREFERENCES_ICON_VIEW_FONT,
 						  font_changed_callback, 
 						  icon_view,
