@@ -109,7 +109,7 @@ event_loop_unregister (GtkObject *object)
 void
 nautilus_main_event_loop_register (GtkObject *object)
 {
-	gtk_signal_connect (object, "destroy", G_CALLBACK (event_loop_unregister), NULL);
+	g_signal_connect (object, "destroy", G_CALLBACK (event_loop_unregister), NULL);
 	event_loop_registrants = g_slist_prepend (event_loop_registrants, object);
 }
 
@@ -167,14 +167,9 @@ main (int argc, char *argv[])
 	}
 	
 	/* Initialize gettext support */
-	/* Sadly, we need this ifdef because otherwise the following
-	 * lines cause empty statement warnings.
-	 */
-#ifdef ENABLE_NLS
-	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
-	bind_textdomain_codeset (PACKAGE, "UTF-8");
-	textdomain (PACKAGE);
-#endif
+	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+	textdomain (GETTEXT_PACKAGE);
 
 	/* Get parameters. */
 	geometry = NULL;
