@@ -71,6 +71,9 @@
 #define TAB_ACTIVE_PRELIGHT_RIGHT 	18
 #define LAST_TAB_OFFSET			19
 
+/* FIXME: Hard coded font size */
+#define DEFAULT_FONT_SIZE 9
+
 #define RIGHT_MARGIN_WIDTH 12
 
 /* data structures */
@@ -82,7 +85,7 @@ typedef struct {
 	char *indicator_pixbuf_name;
 	GdkPixbuf *indicator_pixbuf;
 	int notebook_page;
-	Bonobo_EventSource_ListenerId listener_id;
+	Bonobo_Listener listener;
 	GtkWidget *tab_view;
 	GdkRectangle tab_rect;
 } TabItem;
@@ -101,6 +104,7 @@ struct NautilusSidebarTabsDetails {
 	GdkColor prelit_text_color;
 
 	GdkPixbuf *tab_piece_images[LAST_TAB_OFFSET];
+	PangoFontDescription *tab_font;
 	int tab_height;
 	int tab_left_offset;
 	char *title;
@@ -134,6 +138,7 @@ static void     draw_or_layout_all_tabs                 (NautilusSidebarTabs
 							 gboolean                  layout_only);
 static TabItem* tab_item_find_by_name                   (NautilusSidebarTabs      *sidebar_tabs,
 							 const char               *name);
+static void     default_font_changed_callback           (gpointer                  callback_data);
 
 EEL_CLASS_BOILERPLATE (NautilusSidebarTabs, nautilus_sidebar_tabs, GTK_TYPE_WIDGET)
 
@@ -232,36 +237,27 @@ nautilus_sidebar_tabs_load_theme_data (NautilusSidebarTabs *sidebar_tabs)
 		}	
 	}	
 
-#if GNOME2_CONVERSION_COMPLETE
-	/* unload the old font if necessary */
-	if (sidebar_tabs->details->tab_font != NULL) {
-		g_object_unref (sidebar_tabs->details->tab_font);
-		sidebar_tabs->details->tab_font = NULL;
-	}
-
-	smooth_font_changed_callback (sidebar_tabs);
-
-	/* FIXME: Hard coded font size */
-	sidebar_tabs->details->font_size = DEFAULT_FONT_SIZE;
-#endif
+	default_font_changed_callback (sidebar_tabs);
 }
 
-#if GNOME2_CONVERSION_COMPLETE
-
 /* Use the font from preferences */
 static void
-smooth_font_changed_callback (gpointer callback_data)
+default_font_changed_callback (gpointer callback_data)
 {
-	EelScalableFont *new_font;
+	PangoFontDescription *new_font;
+	char *font_name;
 	NautilusSidebarTabs *sidebar_tabs;
 
 	g_return_if_fail (NAUTILUS_IS_SIDEBAR_TABS (callback_data));
 
 	sidebar_tabs = NAUTILUS_SIDEBAR_TABS (callback_data);
-	new_font = nautilus_global_preferences_get_default_smooth_bold_font ();
 
+	font_name = eel_preferences_get (NAUTILUS_PREFERENCES_DEFAULT_FONT);
+	new_font = pango_font_description_from_string (font_name);
+	pango_font_description_set_size (new_font, DEFAULT_FONT_SIZE * PANGO_SCALE);
+	
 	if (sidebar_tabs->details->tab_font != NULL) {
-		g_object_unref (sidebar_tabs->details->tab_font);
+		pango_font_description_free (sidebar_tabs->details->tab_font);
 		sidebar_tabs->details->tab_font = NULL;
 	}
 
@@ -270,8 +266,6 @@ smooth_font_changed_callback (gpointer callback_data)
 	gtk_widget_queue_resize (GTK_WIDGET (sidebar_tabs));
 }
 
-#endif
-
 /* initialize a newly allocated sidebar tabs object */
 static void
 nautilus_sidebar_tabs_init (NautilusSidebarTabs *sidebar_tabs)
@@ -308,11 +302,10 @@ nautilus_sidebar_tabs_init (NautilusSidebarTabs *sidebar_tabs)
 	eel_preferences_add_callback(NAUTILUS_PREFERENCES_THEME, 
 				     (EelPreferencesCallback) nautilus_sidebar_tabs_load_theme_data, 
 				     sidebar_tabs);
-#if GNOME2_CONVERSION_COMPLETE
-	eel_preferences_add_callback (NAUTILUS_PREFERENCES_DEFAULT_SMOOTH_FONT,
-				      smooth_font_changed_callback,
+
+	eel_preferences_add_callback (NAUTILUS_PREFERENCES_DEFAULT_FONT,
+				      default_font_changed_callback,
 				      sidebar_tabs);
-#endif
 	
 	sidebar_tabs->details->title_prelit = FALSE;
 }
@@ -349,6 +342,7 @@ static void
 tab_item_destroy (TabItem *item)
 {
 	Bonobo_PropertyBag property_bag;
+	CORBA_Environment ev;
 
 	g_free (item->tab_text);
 	g_free (item->indicator_pixbuf_name);
@@ -357,16 +351,20 @@ tab_item_destroy (TabItem *item)
 		g_object_unref (item->indicator_pixbuf);
 	}
 
-	if (item->listener_id != 0) {
+	if (item->listener != CORBA_OBJECT_NIL) {
+		CORBA_exception_init (&ev);
+
 		property_bag = get_property_bag (item);
-		if (property_bag != CORBA_OBJECT_NIL) {	
-#ifdef GNOME2_CONVERSION_COMPLETE
+		if (property_bag != CORBA_OBJECT_NIL) {
 			bonobo_event_source_client_remove_listener
-				(property_bag, item->listener_id, NULL);
-#endif
-			bonobo_object_release_unref (property_bag, NULL);
+				(property_bag, item->listener, &ev);
+			bonobo_object_release_unref (property_bag, &ev);
 		}
+		CORBA_Object_release (item->listener, &ev);
+
+		CORBA_exception_free (&ev);
 	}
+
 	g_free (item);
 }
 
@@ -402,12 +400,13 @@ nautilus_sidebar_tabs_destroy (GtkObject *object)
 		eel_preferences_remove_callback (NAUTILUS_PREFERENCES_THEME, 
 						 (EelPreferencesCallback) nautilus_sidebar_tabs_load_theme_data, 
 						 sidebar_tabs);
-#if GNOME2_CONVERSION_COMPLETE
-		eel_preferences_remove_callback (NAUTILUS_PREFERENCES_DEFAULT_SMOOTH_FONT,
-						 smooth_font_changed_callback,
+
+		eel_preferences_remove_callback (NAUTILUS_PREFERENCES_DEFAULT_FONT,
+						 default_font_changed_callback,
 						 sidebar_tabs);
-#endif
-	
+
+		pango_font_description_free (sidebar_tabs->details->tab_font);
+		
 		g_free (sidebar_tabs->details);
 		sidebar_tabs->details = NULL;
 	}
@@ -619,7 +618,8 @@ draw_one_tab_plain (NautilusSidebarTabs *sidebar_tabs, GdkGC *gc, char *tab_name
 
 	layout = pango_layout_new (eel_gtk_widget_get_pango_ft2_context (GTK_WIDGET (sidebar_tabs)));
 	pango_layout_set_text (layout, tab_name, -1);
-
+	pango_layout_set_font_description (layout, sidebar_tabs->details->tab_font);
+	
 	pango_layout_get_pixel_size (layout, &text_width, &text_height);
 
 	total_width = text_width + indicator_width + 2 * TAB_MARGIN;
@@ -797,7 +797,8 @@ draw_one_tab_themed (NautilusSidebarTabs *sidebar_tabs, GdkPixbuf *tab_pixbuf, G
 	/* measure the size of the name */
 	layout = pango_layout_new (eel_gtk_widget_get_pango_ft2_context (GTK_WIDGET (sidebar_tabs)));
 	pango_layout_set_text (layout, tab_name, -1);
-
+	pango_layout_set_font_description (layout, sidebar_tabs->details->tab_font);
+	
 	pango_layout_get_pixel_size (layout, &text_width, NULL);
 
 	/* draw the left edge piece */
@@ -1200,7 +1201,7 @@ draw_or_layout_all_tabs (NautilusSidebarTabs *sidebar_tabs, gboolean layout_only
 	
 	/* draw the off-screen buffer to the screen, then release it */
 	if (!layout_only) {
-		gdk_gc_unref(temp_gc);
+		g_object_unref(temp_gc);
 		if (is_themed) {
 			/* draw the pixbuf onto the widget and release it */
 			gdk_pixbuf_render_to_drawable_alpha (tab_pixbuf,
@@ -1300,7 +1301,7 @@ nautilus_sidebar_tabs_expose (GtkWidget *widget, GdkEventExpose *event)
 			draw_one_tab_plain (sidebar_tabs, temp_gc, sidebar_tabs->details->title, NULL,
 					    x_pos + TITLE_TAB_OFFSET, y_pos, sidebar_tabs->details->title_prelit, &sidebar_tabs->details->title_rect);
 		}
-		gdk_gc_unref (temp_gc);
+		g_object_unref (temp_gc);
 		
 	} else {
 		if (sidebar_tabs->details->tab_count > 0) {
@@ -1376,8 +1377,6 @@ get_tab_item_from_view (NautilusSidebarTabs *sidebar_tabs, GtkWidget *view)
 	return NULL;
 }
 
-#ifdef GNOME2_CONVERSION_COMPLETE
-
 /* check all of the tabs to see if their indicator pixmaps are ready for updating */
 static void
 nautilus_sidebar_tabs_update_all_indicators (NautilusSidebarTabs *sidebar_tabs)
@@ -1391,8 +1390,6 @@ nautilus_sidebar_tabs_update_all_indicators (NautilusSidebarTabs *sidebar_tabs)
 	}
 }
 
-#endif
-
 /* check all of the tabs to see if their indicator pixmaps are ready for updating */
 static void
 nautilus_sidebar_tabs_update_indicator (NautilusSidebarTabs *sidebar_tabs, GtkWidget *view)
@@ -1409,12 +1406,10 @@ nautilus_sidebar_tabs_update_indicator (NautilusSidebarTabs *sidebar_tabs, GtkWi
 	}
 }
 
-#if GNOME2_CONVERSION_COMPLETE
-
 static void
 tab_indicator_changed_callback (BonoboListener *listener,
-				char *event_name,
-				CORBA_any *arg,
+				const char *event_name,
+				const CORBA_any *arg,
 				CORBA_Environment *ev,
 				gpointer callback_data)
 {
@@ -1424,8 +1419,6 @@ tab_indicator_changed_callback (BonoboListener *listener,
 	nautilus_sidebar_tabs_update_all_indicators (sidebar_tabs);	
 }
 
-#endif
-
 /* listen for changes on the tab_image property */
 void
 nautilus_sidebar_tabs_connect_view (NautilusSidebarTabs *sidebar_tabs, GtkWidget *view)
@@ -1440,11 +1433,10 @@ nautilus_sidebar_tabs_connect_view (NautilusSidebarTabs *sidebar_tabs, GtkWidget
 	
 	property_bag = get_property_bag (tab_item);
 	if (property_bag != CORBA_OBJECT_NIL) {
-#ifdef GNOME2_CONVERSION_COMPLETE
-		tab_item->listener_id = bonobo_event_source_client_add_listener
-			(property_bag, tab_indicator_changed_callback, 
-			 "Bonobo/Property:change:tab_image", NULL, sidebar_tabs); 
-#endif
+		tab_item->listener = bonobo_event_source_client_add_listener_full
+			(property_bag,
+			 g_cclosure_new (G_CALLBACK (tab_indicator_changed_callback), sidebar_tabs, NULL), 
+			 "Bonobo/Property:change:tab_image", NULL); 
 		bonobo_object_release_unref (property_bag, NULL);
 	}
 
@@ -1612,8 +1604,8 @@ nautilus_sidebar_tabs_set_color (NautilusSidebarTabs *sidebar_tabs,
 {
 	g_return_if_fail (NAUTILUS_IS_SIDEBAR_TABS (sidebar_tabs));
 	g_return_if_fail (color_spec != NULL);
-	
-	gdk_color_parse (color_spec, &sidebar_tabs->details->tab_color);
+
+	eel_gdk_color_parse (color_spec, &sidebar_tabs->details->tab_color);
 	gdk_colormap_alloc_color (gtk_widget_get_colormap (GTK_WIDGET (sidebar_tabs)), 
 				  &sidebar_tabs->details->tab_color, FALSE, TRUE);
 
