@@ -34,14 +34,13 @@
 #include <eel/eel-image-chooser.h>
 #include <eel/eel-stock-dialogs.h>
 #include <eel/eel-string.h>
-#include <eel/eel-viewport.h>
 #include <gtk/gtkalignment.h>
 #include <gtk/gtkbutton.h>
 #include <gtk/gtkfilesel.h>
 #include <gtk/gtkhbox.h>
 #include <gtk/gtkmain.h>
+#include <gtk/gtkscrolledwindow.h>
 #include <gtk/gtksignal.h>
-#include <gtk/gtkwindow.h>
 #include <libgnome/gnome-i18n.h>
 #include <libgnome/gnome-util.h>
 #include <libnautilus-private/nautilus-global-preferences.h>
@@ -135,13 +134,13 @@ make_widgets_same_size (GtkWidget *one, GtkWidget *two)
 	one_dimensions = eel_gtk_widget_get_preferred_dimensions (one);
 	two_dimensions = eel_gtk_widget_get_preferred_dimensions (two);
 
-	gtk_widget_set_usize (one,
-			      MAX (one_dimensions.width, two_dimensions.width),
-			      MAX (one_dimensions.height, two_dimensions.height));
+	gtk_widget_set_size_request (one,
+				     MAX (one_dimensions.width, two_dimensions.width),
+				     MAX (one_dimensions.height, two_dimensions.height));
 
-	gtk_widget_set_usize (two,
-			      MAX (one_dimensions.width, two_dimensions.width),
-			      MAX (one_dimensions.height, two_dimensions.height));
+	gtk_widget_set_size_request (two,
+				     MAX (one_dimensions.width, two_dimensions.width),
+				     MAX (one_dimensions.height, two_dimensions.height));
 }
 
 static void
@@ -329,8 +328,6 @@ install_theme_button_clicked_callback (GtkWidget *button,
 	theme_selector = NAUTILUS_THEME_SELECTOR (callback_data);
 	file_selection_dialog = gtk_file_selection_new (_("Select a theme folder to add as a new theme:"));
 
-	eel_gtk_window_set_up_close_accelerator (GTK_WINDOW (file_selection_dialog));
-
 	g_object_set_data (G_OBJECT (file_selection_dialog),
 			   THEME_SELECTOR_DATA_KEY,
 			   callback_data);
@@ -455,11 +452,11 @@ remove_theme_selector_changed_callback (EelImageChooser *image_chooser,
 
 	theme_to_remove = g_strdup ((const char *)eel_image_chooser_get_row_data (image_chooser, theme_to_remove_position));
 
-	gtk_signal_handler_block (GTK_OBJECT (theme_selector->details->remove_theme_selector),
-				  theme_selector->details->theme_selector_changed_connection);
+	g_signal_handler_block (theme_selector->details->remove_theme_selector,
+				theme_selector->details->theme_selector_changed_connection);
 	theme_selector_finish_remove (theme_selector);
-	gtk_signal_handler_unblock (GTK_OBJECT (theme_selector->details->remove_theme_selector),
-				    theme_selector->details->theme_selector_changed_connection);
+	g_signal_handler_unblock (theme_selector->details->remove_theme_selector,
+				  theme_selector->details->theme_selector_changed_connection);
 
 	selected_theme = theme_selector_get_selected_theme (theme_selector);
 	g_return_if_fail (selected_theme != NULL);
