@@ -35,11 +35,11 @@
 #include "nautilus-signaller.h"
 #include "nautilus-view-frame-private.h"
 #include "nautilus-window.h"
+#include <nautilus-marshal.h>
 #include <bonobo/bonobo-event-source.h>
 #include <bonobo/bonobo-control-frame.h>
 #include <bonobo/bonobo-zoomable-frame.h>
 #include <bonobo/bonobo-zoomable.h>
-#include <eel/eel-gobject-extensions.h>
 #include <eel/eel-gtk-extensions.h>
 #include <eel/eel-gtk-macros.h>
 #include <eel/eel-marshal.h>
@@ -152,14 +152,10 @@ nautilus_view_frame_init (NautilusViewFrame *view)
 
 	view->details->idle_queue = nautilus_idle_queue_new ();
 
-	eel_signal_connect_object_while_alive (G_OBJECT (nautilus_signaller_get_current ()),
-					       "history_list_changed",
-					       G_CALLBACK (send_history),
-					       G_OBJECT (view));
-	eel_signal_connect_object_while_alive (G_OBJECT (nautilus_icon_factory_get ()),
-					       "icons_changed",
-					       G_CALLBACK (send_history),
-					       G_OBJECT (view));
+	g_signal_connect_object (nautilus_signaller_get_current (), "history_list_changed",
+				 G_CALLBACK (send_history), view, G_CONNECT_SWAPPED);
+	g_signal_connect_object (nautilus_icon_factory_get (), "icons_changed",
+				 G_CALLBACK (send_history), view, G_CONNECT_SWAPPED);
 }
 
 static void
@@ -172,6 +168,7 @@ stop_activation (NautilusViewFrame *view)
 static void
 destroy_view (NautilusViewFrame *view)
 {
+	BonoboUIEngine *engine;
 	CORBA_Environment ev;
 
 	if (view->details->view == CORBA_OBJECT_NIL) {
@@ -191,11 +188,10 @@ destroy_view (NautilusViewFrame *view)
 	view->details->control_frame = NULL;
 	view->details->zoomable_frame = NULL;
 
-#if GNOME2_CONVERSION_COMPLETE
-	if (view->details->ui_container->win != NULL) {
-		bonobo_window_deregister_dead_components (view->details->ui_container->win);
+	engine = bonobo_ui_container_get_engine (view->details->ui_container);
+	if (engine != NULL) {
+		bonobo_ui_engine_deregister_dead_components (engine);
 	}
-#endif
 	bonobo_object_unref (BONOBO_OBJECT (view->details->ui_container));
 	view->details->ui_container = NULL;
 }
@@ -592,8 +588,8 @@ create_corba_objects (NautilusViewFrame *view)
 	control = Bonobo_Unknown_queryInterface
 		(view->details->view, "IDL:Bonobo/Control:1.0", &ev);
 	g_assert (ev._major == CORBA_NO_EXCEPTION);
-	view->details->control_frame = bonobo_control_frame_new
-		(bonobo_object_corba_objref (BONOBO_OBJECT (view->details->ui_container)));
+	view->details->control_frame = bonobo_control_frame_new (
+		BONOBO_OBJREF (view->details->ui_container));
 
 	bonobo_control_frame_set_propbag (
 		view->details->control_frame,
@@ -668,7 +664,7 @@ check_socket_gone_idle_callback (gpointer callback_data)
 	 * hierarchy between the widget returned by get_widget and the
 	 * actual plug.
 	 */
-	children = gtk_container_children (GTK_CONTAINER (widget));
+	children = gtk_container_get_children (GTK_CONTAINER (widget));
 	g_list_free (children);
 
 	/* If there's nothing inside the widget at all, that means
@@ -733,42 +729,22 @@ attach_view (NautilusViewFrame *view,
 
 	widget = bonobo_control_frame_get_widget (view->details->control_frame);
 
-	eel_signal_connect_object_while_alive
-		(G_OBJECT (view->details->view_frame),
-		 "destroy",
-		 G_CALLBACK (view_frame_failed), G_OBJECT (view));
-	eel_signal_connect_object_while_alive
-		(G_OBJECT (view->details->view_frame),
-		 "system_exception",
-		 G_CALLBACK (queue_view_frame_failed), G_OBJECT (view));
-
-	eel_signal_connect_object_while_alive
-		(G_OBJECT (view->details->control_frame),
-		 "system_exception",
-		 G_CALLBACK (queue_view_frame_failed), G_OBJECT (view));
-
-	eel_signal_connect_while_alive
-		(G_OBJECT (widget),
-		 "remove",
-		 G_CALLBACK (check_socket_gone_callback), view,
-		 G_OBJECT (view));
+	g_signal_connect_object	(view->details->view_frame, "destroy",
+				 G_CALLBACK (view_frame_failed), view, G_CONNECT_SWAPPED);
+	g_signal_connect_object	(view->details->view_frame, "system_exception",
+				 G_CALLBACK (queue_view_frame_failed), view, G_CONNECT_SWAPPED);
+	g_signal_connect_object	(view->details->control_frame, "system_exception",
+				 G_CALLBACK (queue_view_frame_failed), view, G_CONNECT_SWAPPED);
+	g_signal_connect_object	(widget, "remove",
+				 G_CALLBACK (check_socket_gone_callback), view, 0);
 
 	if (view->details->zoomable_frame != NULL) {
-		eel_signal_connect_object_while_alive
-			(G_OBJECT (view->details->zoomable_frame),
-			 "system_exception",
-			 G_CALLBACK (queue_view_frame_failed), G_OBJECT (view));
-
-		eel_signal_connect_while_alive
-			(G_OBJECT (view->details->zoomable_frame),
-			 "zoom_parameters_changed",
-			 G_CALLBACK (zoom_parameters_changed_callback), view,
-			 G_OBJECT (view));
-		eel_signal_connect_while_alive
-			(G_OBJECT (view->details->zoomable_frame),
-			 "zoom_level_changed",
-			 G_CALLBACK (zoom_level_changed_callback), view,
-			 G_OBJECT (view));
+		g_signal_connect_object	(view->details->zoomable_frame, "system_exception",
+					 G_CALLBACK (queue_view_frame_failed), view, G_CONNECT_SWAPPED);
+		g_signal_connect_object (view->details->zoomable_frame, "zoom_parameters_changed",
+					 G_CALLBACK (zoom_parameters_changed_callback), view, 0);
+		g_signal_connect_object (view->details->zoomable_frame, "zoom_level_changed",
+					 G_CALLBACK (zoom_level_changed_callback), view, 0);
 	}
 
 	gtk_widget_show (widget);
@@ -886,7 +862,8 @@ nautilus_view_frame_selection_changed (NautilusViewFrame *view,
 	CORBA_exception_init (&ev);
 
 	arg = bonobo_arg_new_from (TC_Nautilus_URIList, uri_list);
-
+	CORBA_free (uri_list);
+	
 	bonobo_event_source_notify_listeners (
 		view->details->event_source,
 		"Bonobo/Property:change:selection", arg, &ev);
@@ -1355,6 +1332,8 @@ send_history (NautilusViewFrame *view)
 
 	arg = bonobo_arg_new_from (TC_Nautilus_History, history);
 
+	CORBA_free (history);
+	
 	bonobo_event_source_notify_listeners (
 		view->details->event_source,
 		"Bonobo/Property:change:history", arg, &ev);
@@ -1402,7 +1381,7 @@ nautilus_view_frame_class_init (NautilusViewFrameClass *class)
 		 G_STRUCT_OFFSET (NautilusViewFrameClass, 
 				  change_selection),
 		 NULL, NULL,
-		 gtk_marshal_VOID__POINTER,
+		 g_cclosure_marshal_VOID__POINTER,
 		 G_TYPE_NONE, 1, G_TYPE_POINTER);
 	signals[CHANGE_STATUS] = g_signal_new
 		("change_status",
@@ -1420,7 +1399,7 @@ nautilus_view_frame_class_init (NautilusViewFrameClass *class)
 		 G_STRUCT_OFFSET (NautilusViewFrameClass, 
 				  failed),
 		 NULL, NULL,
-		 gtk_marshal_VOID__VOID,
+		 g_cclosure_marshal_VOID__VOID,
 		 G_TYPE_NONE, 0);
 	signals[GET_HISTORY_LIST] = g_signal_new
 		("get_history_list",
@@ -1438,7 +1417,7 @@ nautilus_view_frame_class_init (NautilusViewFrameClass *class)
 		 G_STRUCT_OFFSET (NautilusViewFrameClass, 
 				  go_back),
 		 NULL, NULL,
-		 gtk_marshal_VOID__VOID,
+		 g_cclosure_marshal_VOID__VOID,
 		 G_TYPE_NONE, 0);
 	signals[CLOSE_WINDOW] = g_signal_new
 		("close_window",
@@ -1447,7 +1426,7 @@ nautilus_view_frame_class_init (NautilusViewFrameClass *class)
 		 G_STRUCT_OFFSET (NautilusViewFrameClass, 
 				  close_window),
 		 NULL, NULL,
-		 gtk_marshal_VOID__VOID,
+		 g_cclosure_marshal_VOID__VOID,
 		 G_TYPE_NONE, 0);
 	signals[LOAD_COMPLETE] = g_signal_new
 		("load_complete",
@@ -1456,7 +1435,7 @@ nautilus_view_frame_class_init (NautilusViewFrameClass *class)
 		 G_STRUCT_OFFSET (NautilusViewFrameClass, 
 				  load_complete),
 		 NULL, NULL,
-		 gtk_marshal_VOID__VOID,
+		 g_cclosure_marshal_VOID__VOID,
 		 G_TYPE_NONE, 0);
 	signals[LOAD_PROGRESS_CHANGED] = g_signal_new
 		("load_progress_changed",
@@ -1465,7 +1444,7 @@ nautilus_view_frame_class_init (NautilusViewFrameClass *class)
 		 G_STRUCT_OFFSET (NautilusViewFrameClass, 
 				  load_progress_changed),
 		 NULL, NULL,
-		 gtk_marshal_VOID__VOID,
+		 g_cclosure_marshal_VOID__VOID,
 		 G_TYPE_NONE, 0);
 	signals[LOAD_UNDERWAY] = g_signal_new
 		("load_underway",
@@ -1474,7 +1453,7 @@ nautilus_view_frame_class_init (NautilusViewFrameClass *class)
 		 G_STRUCT_OFFSET (NautilusViewFrameClass, 
 				  load_underway),
 		 NULL, NULL,
-		 gtk_marshal_VOID__VOID,
+		 g_cclosure_marshal_VOID__VOID,
 		 G_TYPE_NONE, 0);
 	signals[OPEN_LOCATION_FORCE_NEW_WINDOW] = g_signal_new
 		("open_location_force_new_window",
@@ -1528,7 +1507,7 @@ nautilus_view_frame_class_init (NautilusViewFrameClass *class)
 		 G_STRUCT_OFFSET (NautilusViewFrameClass, 
 				  title_changed),
 		 NULL, NULL,
-		 gtk_marshal_VOID__VOID,
+		 g_cclosure_marshal_VOID__VOID,
 		 G_TYPE_NONE, 0);
 	signals[VIEW_LOADED] = g_signal_new
 		("view_loaded",
@@ -1537,7 +1516,7 @@ nautilus_view_frame_class_init (NautilusViewFrameClass *class)
 		 G_STRUCT_OFFSET (NautilusViewFrameClass, 
 				  view_loaded),
 		 NULL, NULL,
-		 gtk_marshal_VOID__VOID,
+		 g_cclosure_marshal_VOID__VOID,
 		 G_TYPE_NONE, 0);
 	signals[ZOOM_LEVEL_CHANGED] = g_signal_new
 		("zoom_level_changed",
@@ -1546,7 +1525,7 @@ nautilus_view_frame_class_init (NautilusViewFrameClass *class)
 		 G_STRUCT_OFFSET (NautilusViewFrameClass, 
 				  zoom_level_changed),
 		 NULL, NULL,
-		 gtk_marshal_VOID__VOID,
+		 g_cclosure_marshal_VOID__VOID,
 		 G_TYPE_NONE, 0);
 	signals[ZOOM_PARAMETERS_CHANGED] = g_signal_new
 		("zoom_parameters_changed",
@@ -1555,6 +1534,6 @@ nautilus_view_frame_class_init (NautilusViewFrameClass *class)
 		 G_STRUCT_OFFSET (NautilusViewFrameClass, 
 				  zoom_parameters_changed),
 		 NULL, NULL,
-		 gtk_marshal_VOID__VOID,
+		 g_cclosure_marshal_VOID__VOID,
 		 G_TYPE_NONE, 0);
 }
