@@ -537,9 +537,9 @@ static void
 cancel_viewed_file_changed_callback (NautilusWindow *window)
 {
         if (window->details->viewed_file != NULL) {
-                gtk_signal_disconnect_by_func (GTK_OBJECT (window->details->viewed_file),
-                                               G_CALLBACK (viewed_file_changed_callback),
-                                               window);
+                g_signal_handlers_disconnect_by_func (window->details->viewed_file,
+                                                      G_CALLBACK (viewed_file_changed_callback),
+                                                      window);
         }
 }
 
@@ -1326,7 +1326,18 @@ determined_initial_view_callback (NautilusDetermineViewHandle *handle,
                                    "don't have an index, that the Medusa indexer is running."));
 			dialog_title = g_strdup (_("Searching Unavailable"));
 			break;
-		} /* else fall through */
+		} else {
+			/* This is a special case for the smb: module */
+			if (eel_istr_has_prefix(location, "smb:") == 0)
+			{
+				error_message = g_strdup_printf
+					(_("Couldn't display \"%s\", because Nautilus cannot contact the SMB master browser.\n"
+					"Check that an SMB server is running in the local network."),
+					uri_for_display);
+				break;
+			}
+		}
+		/* else fall through */
         default:
                 error_message = g_strdup_printf (_("Nautilus cannot display \"%s\"."),
                                                  uri_for_display);
@@ -1348,18 +1359,20 @@ determined_initial_view_callback (NautilusDetermineViewHandle *handle,
 			/* the user could have typed in a home directory that doesn't exist,
 			   in which case going home would cause an infinite loop, so we
 			   better test for that */
-			
-			home_uri = eel_preferences_get (NAUTILUS_PREFERENCES_HOME_URI);
-			if (!eel_uris_match (home_uri, location)) {	
-				nautilus_window_go_home (NAUTILUS_WINDOW (window));
-			} else {
+
+                        if (!eel_uris_match (location, "file:///")) {
+                                home_uri = eel_preferences_get (NAUTILUS_PREFERENCES_HOME_URI);
+                                if (!eel_uris_match (home_uri, location)) {	
+                                        nautilus_window_go_home (NAUTILUS_WINDOW (window));
+                                } else {
 				/* the last fallback is to go to a known place that can't be deleted! */
-				nautilus_window_go_to (NAUTILUS_WINDOW (window), "file:///");
-			}
-			g_free (home_uri);
+                                        nautilus_window_go_to (NAUTILUS_WINDOW (window), "file:///");
+                                }
+                                g_free (home_uri);
+                        }
 		} else {
-                /* Since this is a window, destroying it will also unref it. */
-                gtk_object_destroy (GTK_OBJECT (window));
+                        /* Since this is a window, destroying it will also unref it. */
+                        gtk_object_destroy (GTK_OBJECT (window));
        		}
         } else {
                 /* Clean up state of already-showing window */
@@ -1976,12 +1989,8 @@ view_loaded_callback (NautilusViewFrame *view,
 static void
 connect_view (NautilusWindow *window, NautilusViewFrame *view)
 {
-	GtkObject *view_object;
-	
-	view_object = GTK_OBJECT (view);
-
-	#define CONNECT(signal) gtk_signal_connect \
-        	(view_object, #signal, \
+	#define CONNECT(signal) g_signal_connect \
+        	(view, #signal, \
                  G_CALLBACK (signal##_callback), window);
         FOR_EACH_NAUTILUS_WINDOW_SIGNAL (CONNECT)
 	#undef CONNECT
@@ -1990,8 +1999,6 @@ connect_view (NautilusWindow *window, NautilusViewFrame *view)
 static void
 disconnect_view (NautilusWindow *window, NautilusViewFrame *view)
 {
-	GtkObject *view_object;
-	
 	g_assert (NAUTILUS_IS_WINDOW (window));
 
 	if (view == NULL) {
@@ -2000,10 +2007,8 @@ disconnect_view (NautilusWindow *window, NautilusViewFrame *view)
 
 	g_assert (NAUTILUS_IS_VIEW_FRAME (view));
 
-	view_object = GTK_OBJECT (view);
-
-#define DISCONNECT(signal) gtk_signal_disconnect_by_func \
-        	(view_object, \
+#define DISCONNECT(signal) g_signal_handlers_disconnect_by_func \
+        	(view, \
         	 G_CALLBACK (signal##_callback), window);
         FOR_EACH_NAUTILUS_WINDOW_SIGNAL (DISCONNECT)
 #undef DISCONNECT
