@@ -16,8 +16,6 @@
 #include <eel/eel-glib-extensions.h>
 #include <eel/eel-gnome-extensions.h>
 #include <eel/eel-gtk-extensions.h>
-#include <eel/eel-image-with-background.h>
-#include <eel/eel-image.h>
 #include <eel/eel-string-list.h>
 #include <eel/eel-string.h>
 #include <libnautilus-private/nautilus-file-utilities.h>
@@ -39,9 +37,6 @@ void       test_gtk_widget_set_background_color (GtkWidget                   *wi
 						 const char                  *color_spec);
 GdkPixbuf *test_pixbuf_new_named                (const char                  *name,
 						 float                        scale);
-GtkWidget *test_image_new                       (const char                  *pixbuf_name,
-						 float                        scale,
-						 gboolean                     with_background);
 GtkWidget *test_label_new                       (const char                  *text,
 						 gboolean                     with_background,
 						 int                          num_sizes_larger);
